Tool execution helpers extracted from loop_.
Contains the functions responsible for invoking tools (single, parallel, sequential) and the decision logic for choosing between parallel and sequential execution.
Tool execution helpers extracted from loop_.
Contains the functions responsible for invoking tools (single, parallel, sequential) and the decision logic for choosing between parallel and sequential execution.