pub struct NotionConfig {
pub enabled: bool,
pub api_key: String,
pub database_id: String,
pub poll_interval_secs: u64,
pub status_property: String,
pub input_property: String,
pub result_property: String,
pub max_concurrent: usize,
pub recover_stale: bool,
}Expand description
Notion integration configuration ([notion]).
When enabled = true, the agent polls a Notion database for pending tasks
and exposes a notion tool for querying, reading, creating, and updating pages.
Requires api_key (or the NOTION_API_KEY env var) and database_id.
Fields
enabled: boolapi_key: Stringdatabase_id: Stringpoll_interval_secs: u64status_property: Stringinput_property: Stringresult_property: Stringmax_concurrent: usizerecover_stale: boolTrait Implementations
Sourceimpl Clone for NotionConfig
impl Clone for NotionConfig
Sourcefn clone(&self) -> NotionConfig
fn clone(&self) -> NotionConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotionConfig
impl Debug for NotionConfig
Sourceimpl Default for NotionConfig
impl Default for NotionConfig
Sourceimpl<'de> Deserialize<'de> for NotionConfig
impl<'de> Deserialize<'de> for NotionConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NotionConfig
impl JsonSchema for NotionConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NotionConfig
impl RefUnwindSafe for NotionConfig
impl Send for NotionConfig
impl Sync for NotionConfig
impl Unpin for NotionConfig
impl UnsafeUnpin for NotionConfig
impl UnwindSafe for NotionConfig