pub struct RuntimeConfig {
pub kind: String,
pub docker: DockerRuntimeConfig,
pub reasoning_enabled: Option<bool>,
pub reasoning_effort: Option<String>,
}Expand description
Runtime adapter configuration ([runtime] section).
Fields
kind: StringRuntime kind (native | docker).
docker: DockerRuntimeConfigDocker runtime settings (used when kind = "docker").
reasoning_enabled: Option<bool>Global reasoning override for providers that expose explicit controls.
None: provider default behaviorSome(true): request reasoning/thinking when supportedSome(false): disable reasoning/thinking when supported
reasoning_effort: Option<String>Optional reasoning effort for providers that expose a level control.