pub struct ProceduralMessage {
pub role: String,
pub content: String,
pub name: Option<String>,
}Expand description
A single message in a conversation trace for procedural memory.
Used to capture “how to” patterns from tool-calling turns so that backends that support procedural storage can learn from them.
Fields
role: Stringcontent: Stringname: Option<String>Trait Implementations
Sourceimpl Clone for ProceduralMessage
impl Clone for ProceduralMessage
Sourcefn clone(&self) -> ProceduralMessage
fn clone(&self) -> ProceduralMessage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProceduralMessage
impl Debug for ProceduralMessage
Sourceimpl<'de> Deserialize<'de> for ProceduralMessage
impl<'de> Deserialize<'de> for ProceduralMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more