detect_python

Function detect_python 

pub fn detect_python(explicit: Option<&str>) -> Result<PathBuf>
Resolve a usable Python interpreter, honoring explicit if provided.

Returns the absolute path to the interpreter on success.