pub enum SopRunAction {
ExecuteStep {
run_id: String,
step: SopStep,
context: String,
},
WaitApproval {
run_id: String,
step: SopStep,
context: String,
},
DeterministicStep {
run_id: String,
step: SopStep,
input: Value,
},
CheckpointWait {
run_id: String,
step: SopStep,
state_file: PathBuf,
},
Completed {
run_id: String,
sop_name: String,
},
Failed {
run_id: String,
sop_name: String,
reason: String,
},
}Expand description
What the engine instructs the caller to do next after a state transition.
Variants
ExecuteStep
Inject this step into the agent for execution.
WaitApproval
Pause and wait for operator approval before executing this step.
DeterministicStep
Execute a step deterministically (no LLM). The input is the piped
output from the previous step (or trigger payload for step 1).
CheckpointWait
Deterministic workflow hit a checkpoint — pause for human approval. Workflow state has been persisted so it can resume after approval.
Completed
The SOP run completed successfully.
Failed
The SOP run failed.