pub struct GoogleWorkspaceTool { /* private fields */ }Expand description
Google Workspace CLI (gws) integration tool.
Wraps the gws CLI binary to give the agent structured access to
Google Workspace services (Drive, Gmail, Calendar, Sheets, etc.).
Requires gws to be installed and authenticated (gws auth login).
Implementations
Sourceimpl GoogleWorkspaceTool
impl GoogleWorkspaceTool
Sourcepub fn new(
security: Arc<SecurityPolicy>,
allowed_services: Vec<String>,
allowed_operations: Vec<GoogleWorkspaceAllowedOperation>,
credentials_path: Option<String>,
default_account: Option<String>,
rate_limit_per_minute: u32,
timeout_secs: u64,
audit_log: bool,
) -> Self
pub fn new( security: Arc<SecurityPolicy>, allowed_services: Vec<String>, allowed_operations: Vec<GoogleWorkspaceAllowedOperation>, credentials_path: Option<String>, default_account: Option<String>, rate_limit_per_minute: u32, timeout_secs: u64, audit_log: bool, ) -> Self
Create a new GoogleWorkspaceTool.
If allowed_services is empty, the default service set is used.