pub type SharedProgressSink = Arc<dyn ProgressSink>;Expand description
Shared/owned sink alias, for callers that need to stash one in a struct.
Aliased Type
pub struct SharedProgressSink { /* private fields */ }pub type SharedProgressSink = Arc<dyn ProgressSink>;Shared/owned sink alias, for callers that need to stash one in a struct.
pub struct SharedProgressSink { /* private fields */ }