Module report_template_tool

Module report_template_tool 

Report template tool โ€” standalone access to template engine.

Exposes the report template engine directly so agents can render templates with custom variable maps without going through ProjectIntelTool.

Structs

ReportTemplateTool
Standalone report template tool.