Process a single message through the full agent (with tools, peripherals, memory).
Used by channels (Telegram, Discord, etc.) to enable hardware and tool use.
Callback type for checking if model has been switched during tool execution.
Returns Some((provider, model)) if a switch was requested, None otherwise.