Wraps a discovered MCP tool as a construct Tool so it is dispatched
through the existing tool registry and agent loop without modification.
Structs
- McpTool
Wrapper - A construct
Toolbacked by an MCP server tool.
Wraps a discovered MCP tool as a construct Tool so it is dispatched
through the existing tool registry and agent loop without modification.
Tool backed by an MCP server tool.